summaryrefslogtreecommitdiffstats
path: root/models/ssh_key_test.go
diff options
context:
space:
mode:
authorGibheer <gibheer+git@zero-knowledge.org>2016-02-23 15:39:05 +0100
committerGibheer <gibheer+git@zero-knowledge.org>2016-02-23 15:39:05 +0100
commit2f27ee2232ca23404baf31443a3cf661d4445232 (patch)
tree47ef17da93d86e8db5fa8081aaa603b277db56fd /models/ssh_key_test.go
parentdab74f21b7b7f9755a8056d17adbd74c185c4199 (diff)
downloadgitea-2f27ee2232ca23404baf31443a3cf661d4445232.tar.gz
gitea-2f27ee2232ca23404baf31443a3cf661d4445232.zip
variable should not use ALL_CAPS
Diffstat (limited to 'models/ssh_key_test.go')
-rw-r--r--models/ssh_key_test.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/models/ssh_key_test.go b/models/ssh_key_test.go
index 697c8d46e2..cfb8554ae2 100644
--- a/models/ssh_key_test.go
+++ b/models/ssh_key_test.go
@@ -21,7 +21,7 @@ func TestSSHKeyVerification(t *testing.T) {
for name, pubkey := range keys {
keyTypeN, lengthN, errN := SSHNativeParsePublicKey(pubkey)
if errN != nil {
- if errN != SSH_UNKNOWN_KEY_TYPE {
+ if errN != SSHUnknownKeyType {
t.Errorf("error parsing public key '%s': %s", name, errN)
continue
}
@@ -31,8 +31,8 @@ func TestSSHKeyVerification(t *testing.T) {
t.Errorf("error parsing public key '%s': %s", name, errK)
continue
}
- // we know that ed25519 is currently not supported by native and returns SSH_UNKNOWN_KEY_TYPE
- if (keyTypeN != keyTypeK || lengthN != lengthK) && errN != SSH_UNKNOWN_KEY_TYPE {
+ // we know that ed25519 is currently not supported by native and returns SSHUnknownKeyType
+ if (keyTypeN != keyTypeK || lengthN != lengthK) && errN != SSHUnknownKeyType {
t.Errorf("key mismatch for '%s': native: %s(%d), ssh-keygen: %s(%d)", name, keyTypeN, lengthN, keyTypeK, lengthK)
}
}